@@ -38,24 +38,20 @@ class SignatureAlgorithmNotSupportedError(Exception):
     pass
 
 
-class KeyExpirationError(Exception):  # pylint: disable=missing-class-docstring
+class KeyExpirationError(Exception):
     def __init__(self, key):
-        super(  # pylint: disable=super-with-arguments
-            KeyExpirationError, self
-        ).__init__()
+        super().__init__()
         self.key = key
 
     def __str__(self):
-        creation_time = datetime.datetime.utcfromtimestamp(
-            self.key["creation_time"]
-        )
+        creation_time = datetime.datetime.utcfromtimestamp(self.key["creation_time"])
         expiration_time = datetime.datetime.utcfromtimestamp(
             self.key["creation_time"] + self.key["validity_period"]
         )
         validity_period = expiration_time - creation_time
 
         return (
-            "GPG key '{}' created on '{:%Y-%m-%d %H:%M} UTC' with validity "  # pylint: disable=consider-using-f-string
+            "GPG key '{}' created on '{:%Y-%m-%d %H:%M} UTC' with validity "
             "period '{}' expired on '{:%Y-%m-%d %H:%M} UTC'.".format(
                 self.key["keyid"],
                 creation_time,
